@@ -1,9 +1,9 @@
-"""Validate and debug DCTAP instances."""
+"""Normalize and debug a TAP (application profile in DCTAP format)."""
 
 from .tapclasses import TAPShape, TAPStatementTemplate
 from .csvreader import csvreader
 
-__version__ = "0.3.6"
+__version__ = "0.3.11"
 
 # Keep version number in sync with:
 # - https://github.com/dcmi/dctap-python/blob/main/docs/conf.py#L28
